package Bundle::AndyA;

$VERSION = '1.02';

1;

__END__

=head1 NAME

Bundle::AndyA - Basic working environment.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::AndyA'>

=head1 CONTENTS

App::Ack

AppConfig::Std

Bundle::CPANxxl

Bundle::LWP

CGI::Simple

Carp

Config::Tiny

Crypt::PerfectPaperPasswords

Cwd

Data::Dumper

Data::Hexdumper

Devel::CheckLib

Devel::CheckOS

Devel::Cover

Devel::Cycle

Devel::Ditto

Devel::Leak::Object

Devel::NYTProf

Devel::Peek

Devel::Size

Devel::StackTrace

Devel::Symdump

Devel::TraceLoad

Devel::Unplug

Digest::MD5

Email::Address

Email::Send

Fcntl

File::Basename

File::Copy

File::Copy::Recursive

File::Find

File::Find::Parallel

File::Monitor

File::Path

File::Slurp

File::Spec

File::Temp

File::Which

File::chdir

GD

Getopt::Long

Getopt::Std

HTML::Tiny

HTML::TokeParser

HTTP::Date

HTTP::Status

IO::Handle

IPC::Open2

IPC::Open3

IPC::Run

IPC::Run3

IPC::ShareLite

IPC::System::Simple

JSON

JavaScript::Beautifier

LWP::Simple

LWP::UserAgent

Lingua::EN::Numbers

List::MoreUtils

List::Util

MIME::Base64

Mail::Send

Memoize

Module::Build

Module::CoreList

Module::Info

Module::Starter::PBP

Moose

Net::FTP

Net::GitHub

Net::TcpDumpLog

Net::Twitter

Net::XMPP

POSIX

PPI

PPI::Find

Parallel::Iterator

Perl::Tidy

Perl::Version

PerlIO::gzip

Pod::Coverage

Pod::Usage

RDF::Simple::Parser

Regexp::Common

Set::IntSpan::Fast

Set::IntSpan::Fast::XS

Storable

Sys::Hostname

Term::ANSIColor

Test::Deep

Test::Differences

Test::Harness

Test::MockModule

Test::MockObject

Text::Autoformat

Text::ParseWords

Text::Wrap

TextMate::JumpTo

Time::HiRes

Time::Local

Time::ParseDate

URI::file

URI::geo

WWW::Plurk

XML::Descent

YAML

attributes

=head1 DESCRIPTION

Nice things to have installed.

=head1 AUTHOR

Andy Armstrong <andy@hexten.net>
